---
title: sql_insert
type: processor
status: stable
categories: ["Integration"]
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the contents of:
     lib/processor/sql_insert.go
-->

import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

Inserts rows into an SQL database for each message, and leaves the message unchanged.

Introduced in version 3.59.0.


<Tabs defaultValue="common" values={[
  { label: 'Common', value: 'common', },
  { label: 'Advanced', value: 'advanced', },
]}>

<TabItem value="common">

```yaml
# Common config fields, showing default values
label: ""
sql_insert:
  driver: ""
  dsn: ""
  table: ""
  columns: []
  args_mapping: ""
```

</TabItem>
<TabItem value="advanced">

```yaml
# All config fields, showing default values
label: ""
sql_insert:
  driver: ""
  dsn: ""
  table: ""
  columns: []
  args_mapping: ""
  prefix: ""
  suffix: ""
```

</TabItem>
</Tabs>

If the insert fails to execute then the message will still remain unchanged and the error can be caught using error handling methods outlined [here](/docs/configuration/error_handling).

## Examples

<Tabs defaultValue="Table Insert (MySQL)" values={[
{ label: 'Table Insert (MySQL)', value: 'Table Insert (MySQL)', },
]}>

<TabItem value="Table Insert (MySQL)">


Here we insert rows into a database by populating the columns id, name and topic with values extracted from messages and metadata:

```yaml
pipeline:
  processors:
    - sql_insert:
        driver: mysql
        dsn: foouser:foopassword@tcp(localhost:3306)/foodb
        table: footable
        columns: [ id, name, topic ]
        args_mapping: |
          root = [
            this.user.id,
            this.user.name,
            meta("kafka_topic"),
          ]
```

</TabItem>
</Tabs>

## Fields

### `driver`

A database [driver](#drivers) to use.


Type: `string`  
Options: `mysql`, `postgres`, `clickhouse`, `mssql`.

### `dsn`

A Data Source Name to identify the target database.

#### Drivers

The following is a list of supported drivers and their respective DSN formats:

| Driver | Data Source Name Format |
|---|---|
| `clickhouse` | [`tcp://[netloc][:port][?param1=value1&...&paramN=valueN]`](https://github.com/ClickHouse/clickhouse-go#dsn)
| `mysql` | `[username[:password]@][protocol[(address)]]/dbname[?param1=value1&...&paramN=valueN]` |
| `postgres` | `postgres://[user[:password]@][netloc][:port][/dbname][?param1=value1&...]` |
| `mssql` | `sqlserver://[user[:password]@][netloc][:port][?database=dbname&param1=value1&...]` |

Please note that the `postgres` driver enforces SSL by default, you
can override this with the parameter `sslmode=disable` if required.


Type: `string`  

```yaml
# Examples

dsn: tcp://host1:9000?username=user&password=qwerty&database=clicks&read_timeout=10&write_timeout=20&alt_hosts=host2:9000,host3:9000

dsn: foouser:foopassword@tcp(localhost:3306)/foodb

dsn: postgres://foouser:foopass@localhost:5432/foodb?sslmode=disable
```

### `table`

The table to insert to.


Type: `string`  

```yaml
# Examples

table: foo
```

### `columns`

A list of columns to insert.


Type: `array`  

```yaml
# Examples

columns:
  - foo
  - bar
  - baz
```

### `args_mapping`

A [Bloblang mapping](/docs/guides/bloblang/about) which should evaluate to an array of values matching in size to the number of columns specified.


Type: `string`  

```yaml
# Examples

args_mapping: root = [ this.cat.meow, this.doc.woofs[0] ]

args_mapping: root = [ meta("user.id") ]
```

### `prefix`

An optional prefix to prepend to the insert query (before INSERT).


Type: `string`  

### `suffix`

An optional suffix to append to the insert query.


Type: `string`  


